@@ -25,7 +25,7 @@ met:
     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in
       the documentation and/or other materials provided with the distribution
-    * Neither the name of the The University of Queensland nor the names
+    * Neither the name of The University of Queensland nor the names
       of its contributors may be used to endorse or promote products derived
       from this software without specific prior written permission.
 
